summaryrefslogtreecommitdiff
path: root/framework/source/jobs/jobdispatch.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'framework/source/jobs/jobdispatch.cxx')
-rw-r--r--framework/source/jobs/jobdispatch.cxx34
1 files changed, 17 insertions, 17 deletions
diff --git a/framework/source/jobs/jobdispatch.cxx b/framework/source/jobs/jobdispatch.cxx
index 03cd4a9bea40..a7e13e1063fa 100644
--- a/framework/source/jobs/jobdispatch.cxx
+++ b/framework/source/jobs/jobdispatch.cxx
@@ -98,19 +98,19 @@ public:
public:
virtual OUString SAL_CALL getImplementationName()
- throw (css::uno::RuntimeException)
+ throw (css::uno::RuntimeException, std::exception)
{
return OUString("com.sun.star.comp.framework.jobs.JobDispatch");
}
virtual sal_Bool SAL_CALL supportsService(OUString const & ServiceName)
- throw (css::uno::RuntimeException)
+ throw (css::uno::RuntimeException, std::exception)
{
return cppu::supportsService(this, ServiceName);
}
virtual css::uno::Sequence<OUString> SAL_CALL getSupportedServiceNames()
- throw (css::uno::RuntimeException)
+ throw (css::uno::RuntimeException, std::exception)
{
css::uno::Sequence< OUString > aSeq(1);
aSeq[0] = OUString("com.sun.star.frame.ProtocolHandler");
@@ -119,26 +119,26 @@ public:
// Xinitialization
virtual void SAL_CALL initialize( const css::uno::Sequence< css::uno::Any >& lArguments ) throw(css::uno::Exception ,
- css::uno::RuntimeException);
+ css::uno::RuntimeException, std::exception);
// XDispatchProvider
virtual css::uno::Reference< css::frame::XDispatch > SAL_CALL queryDispatch ( const css::util::URL& aURL ,
const OUString& sTargetFrameName ,
- sal_Int32 nSearchFlags ) throw(css::uno::RuntimeException);
- virtual css::uno::Sequence< css::uno::Reference< css::frame::XDispatch > > SAL_CALL queryDispatches( const css::uno::Sequence< css::frame::DispatchDescriptor >& lDescriptor ) throw(css::uno::RuntimeException);
+ sal_Int32 nSearchFlags ) throw(css::uno::RuntimeException, std::exception);
+ virtual css::uno::Sequence< css::uno::Reference< css::frame::XDispatch > > SAL_CALL queryDispatches( const css::uno::Sequence< css::frame::DispatchDescriptor >& lDescriptor ) throw(css::uno::RuntimeException, std::exception);
// XNotifyingDispatch
virtual void SAL_CALL dispatchWithNotification( const css::util::URL& aURL ,
const css::uno::Sequence< css::beans::PropertyValue >& lArgs ,
- const css::uno::Reference< css::frame::XDispatchResultListener >& xListener ) throw(css::uno::RuntimeException);
+ const css::uno::Reference< css::frame::XDispatchResultListener >& xListener ) throw(css::uno::RuntimeException, std::exception);
// XDispatch
virtual void SAL_CALL dispatch ( const css::util::URL& aURL ,
- const css::uno::Sequence< css::beans::PropertyValue >& lArgs ) throw(css::uno::RuntimeException);
+ const css::uno::Sequence< css::beans::PropertyValue >& lArgs ) throw(css::uno::RuntimeException, std::exception);
virtual void SAL_CALL addStatusListener ( const css::uno::Reference< css::frame::XStatusListener >& xListener ,
- const css::util::URL& aURL ) throw(css::uno::RuntimeException);
+ const css::util::URL& aURL ) throw(css::uno::RuntimeException, std::exception);
virtual void SAL_CALL removeStatusListener( const css::uno::Reference< css::frame::XStatusListener >& xListener ,
- const css::util::URL& aURL ) throw(css::uno::RuntimeException);
+ const css::util::URL& aURL ) throw(css::uno::RuntimeException, std::exception);
};
@@ -178,7 +178,7 @@ JobDispatch::~JobDispatch()
First parameter should be the frame reference we need.
*/
void SAL_CALL JobDispatch::initialize( const css::uno::Sequence< css::uno::Any >& lArguments ) throw(css::uno::Exception ,
- css::uno::RuntimeException)
+ css::uno::RuntimeException, std::exception)
{
/* SAFE { */
WriteGuard aWriteLock(m_aLock);
@@ -224,7 +224,7 @@ void SAL_CALL JobDispatch::initialize( const css::uno::Sequence< css::uno::Any >
*/
css::uno::Reference< css::frame::XDispatch > SAL_CALL JobDispatch::queryDispatch( /*IN*/ const css::util::URL& aURL ,
/*IN*/ const OUString& /*sTargetFrameName*/ ,
- /*IN*/ sal_Int32 /*nSearchFlags*/ ) throw(css::uno::RuntimeException)
+ /*IN*/ sal_Int32 /*nSearchFlags*/ ) throw(css::uno::RuntimeException, std::exception)
{
css::uno::Reference< css::frame::XDispatch > xDispatch;
@@ -248,7 +248,7 @@ css::uno::Reference< css::frame::XDispatch > SAL_CALL JobDispatch::queryDispatch
NULL references are not skipped. Every result
match to one given descriptor item.
*/
-css::uno::Sequence< css::uno::Reference< css::frame::XDispatch > > SAL_CALL JobDispatch::queryDispatches( const css::uno::Sequence< css::frame::DispatchDescriptor >& lDescriptor ) throw(css::uno::RuntimeException)
+css::uno::Sequence< css::uno::Reference< css::frame::XDispatch > > SAL_CALL JobDispatch::queryDispatches( const css::uno::Sequence< css::frame::DispatchDescriptor >& lDescriptor ) throw(css::uno::RuntimeException, std::exception)
{
// don't pack resulting list!
sal_Int32 nCount = lDescriptor.getLength();
@@ -288,7 +288,7 @@ css::uno::Sequence< css::uno::Reference< css::frame::XDispatch > > SAL_CALL JobD
*/
void SAL_CALL JobDispatch::dispatchWithNotification( /*IN*/ const css::util::URL& aURL ,
/*IN*/ const css::uno::Sequence< css::beans::PropertyValue >& lArgs ,
/*IN*/ const css::uno::Reference< css::frame::XDispatchResultListener >& xListener ) throw(css::uno::RuntimeException)
{
JobURL aAnalyzedURL(aURL.Complete);
if (aAnalyzedURL.isValid())
@@ -506,7 +506,7 @@ void JobDispatch::impl_dispatchAlias( /*IN*/ const OUString&
@see dispatchWithNotification()
*/
void SAL_CALL JobDispatch::dispatch( /*IN*/ const css::util::URL& aURL ,
/*IN*/ const css::uno::Sequence< css::beans::PropertyValue >& lArgs ) throw(css::uno::RuntimeException)
{
dispatchWithNotification(aURL, lArgs, css::uno::Reference< css::frame::XDispatchResultListener >());
}
@@ -516,7 +516,7 @@ void SAL_CALL JobDispatch::dispatch( /*IN*/ const css::util::URL&
@short not supported
*/
void SAL_CALL JobDispatch::addStatusListener( /*IN*/ const css::uno::Reference< css::frame::XStatusListener >&,
- /*IN*/ const css::util::URL& ) throw(css::uno::RuntimeException)
+ /*IN*/ const css::util::URL& ) throw(css::uno::RuntimeException, std::exception)
{
}
@@ -525,7 +525,7 @@ void SAL_CALL JobDispatch::addStatusListener( /*IN*/ const css::uno::Reference<
@short not supported
*/
void SAL_CALL JobDispatch::removeStatusListener( /*IN*/ const css::uno::Reference< css::frame::XStatusListener >&,
- /*IN*/ const css::util::URL& ) throw(css::uno::RuntimeException)
+ /*IN*/ const css::util::URL& ) throw(css::uno::RuntimeException, std::exception)
{
}
@@ -288,7 +288,7 @@ css::uno::Sequence< css::uno::Reference< css::frame::XDispatch > > SAL_CALL JobD
void SAL_CALL JobDispatch::dispatchWithNotification( /*IN*/ const css::util::URL& aURL ,
/*IN*/ const css::uno::Sequence< css::beans::PropertyValue >& lArgs ,
- /*IN*/ const css::uno::Reference< css::frame::XDispatchResultListener >& xListener ) throw(css::uno::RuntimeException)
+ /*IN*/ const css::uno::Reference< css::frame::XDispatchResultListener >& xListener ) throw(css::uno::RuntimeException, std::exception)
{
JobURL aAnalyzedURL(aURL.Complete);
@@ -506,7 +506,7 @@ void JobDispatch::impl_dispatchAlias( /*IN*/ const OUString&
*/
void SAL_CALL JobDispatch::dispatch( /*IN*/ const css::util::URL& aURL ,
- /*IN*/ const css::uno::Sequence< css::beans::PropertyValue >& lArgs ) throw(css::uno::RuntimeException)
+ /*IN*/ const css::uno::Sequence< css::beans::PropertyValue >& lArgs ) throw(css::uno::RuntimeException, std::exception)
{
dispatchWithNotification(aURL, lArgs, css::uno::Reference< css::frame::XDispatchResultListener >());